#ifndef IconCache_h
#define IconCache_h

// $Id: IconCache.h,v 1.1 2012/10/06 13:19:40 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QHash>
#include <QtCore/QPair>
#include <QtGui/QIcon>

namespace BASE
{
    //! cache item
    class IconCacheItem: public QIcon
    {

        public:

        //! constructor
        IconCacheItem( void )
        {}

        //! copy constructor
        IconCacheItem( const QIcon& other ):
            QIcon( other )
        {}

        //! destructor
        virtual ~IconCacheItem( void )
        {}

        //! files
        const QStringList& files( void ) const
        { return files_; }

        //! clear files
        void clearFiles( void )
        { files_.clear(); }

        //! add file
        void addFile( const QString& file )
        { files_ << file; }

        private:

        //! associated files
        QStringList files_;

    };

    //! cache
    class IconCache: public QHash<QString, IconCacheItem>
    {

        public:

        //! constructor
        IconCache( void )
        {}

        //! destructor
        virtual ~IconCache( void )
        {}

        //! pair
        class Pair: public QPair<QString, IconCacheItem >
        {
            public:

            //! constructor
            Pair( void )
            {}

            //! constructor
            Pair( const QString& name, const IconCacheItem& icon ):
                QPair<QString, IconCacheItem >( name, icon )
            {}

            //! constructor
            Pair( const QPair<QString, IconCacheItem >& other ):
                QPair<QString, IconCacheItem >( other )
            {}

            //! destructor
            virtual ~Pair( void )
            {}

            //! equal to operator
            bool operator == ( const Pair& other ) const
            { return first == other.first; }

            //! less than operator
            bool operator < ( const Pair& other ) const
            { return first < other.first; }

        };

    };

}

#endif
