
// $Id: AlienCommand.cpp,v 1.10 2012/09/23 18:54:09 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file    AlienCommand.cpp
\brief   handles Top commands
\author  Hugo Pereira
\version $Revision: 1.10 $
\date    $Date: 2012/09/23 18:54:09 $
*/

#include "AlienCommand.h"

//___________________________________________________________________
unsigned int& AlienCommand::_counter( void )
{
    static unsigned int counter( 0 );
    return counter;
}

//___________________________________________________________________
AlienCommand::AlienCommand( const Type type ):
    Counter( "AlienCommand" ),
    id_( _counter()++ ),
    priority_( 0 ),
    type_( type )
{}

//___________________________________________________________________
QString AlienCommand::name( const Type& type )
{
    Debug::Throw( "AlienCommand::name.\n" );

    if( _names().empty() ) _initializeNames();
    NameMap::const_iterator iter( _names().find( type ) );
    return iter != _names().end() ? iter.value():"";
}

//___________________________________________________________________
QString AlienCommand::user( void ) const
{
    switch( type_ )
    {
        case MASTER_LIST:
        case CHILDREN_LIST:
        case CLEAR_QUEUE:
        case JOB_FILES:
        case JOB_LIST:
        case JOB_STATUS:
        case KILL:
        case KILL_MASTER:
        case TRACE:
        case TRACE_ALL:
        case TRACE_JDL:
        case RESUBMIT:
        case RESUBMIT_MASTER:
        return arguments_[0];

        default: return QString();
    }

}

//___________________________________________________________________
int AlienCommand::parentJobId( void ) const
{
    switch( type_ )
    {
        case RESUBMIT:
        case CHILDREN_LIST:
        case JOB_FILES:
        case JOB_STATUS:
        case TRACE:
        case TRACE_ALL:
        case TRACE_JDL:
        return arguments_[1].toInt();
        default: return -1;
    }
}

//___________________________________________________________________
int AlienCommand::jobId( void ) const
{
    switch( type_ )
    {
        case CHILDREN_LIST:
        case JOB_FILES:
        case JOB_STATUS:
        case KILL:
        case KILL_MASTER:
        case RESUBMIT:
        case RESUBMIT_MASTER:
        case TRACE:
        case TRACE_ALL:
        case TRACE_JDL:
        return arguments_[2].toInt();

        default: return -1;
    }
}

//___________________________________________________________________
QString AlienCommand::path( void ) const
{
    switch( type_ )
    {
        case JOB_FILES: return arguments_[3];
        default: return QString();
    }
}

//___________________________________________________________________
void AlienCommand::_initializeNames( void )
{
    Debug::Throw( "AlienCommand::_initializeNames.\n" );

    _names()[NONE] = "none";
    _names()[COPY]="copy selected remote file";
    _names()[CHILDREN_LIST]="query job children list";
    _names()[DEFAULT_USER]="query default user name";
    _names()[JOB_FILES]="query job output files";
    _names()[JOB_LIST]="query all jobs list";
    _names()[JOB_STATUS]="query job status";
    _names()[KILL]="kill selected job(s)";
    _names()[KILL_MASTER]="kill selected master job(s)";
    _names()[MASTER_LIST]="query master job list";
    _names()[RESUBMIT]="resubmit selected job(s)";
    _names()[RESUBMIT_MASTER]="resubmit selected job(s)";
    _names()[TRACE]="query job information";
    _names()[TRACE_JDL]="query job JDL";
    _names()[TRACE_ALL]="query job information";
    _names()[USER_LIST]="query user list";

    _names()[CLEAR_QUEUE]="clear command queue";

}

//___________________________________________________________________
AlienCommand::NameMap& AlienCommand::_names( void )
{
    static NameMap names;
    return names;
}
