
// $Id: AlienCommandDialog.cpp,v 1.12 2012/10/06 13:21:00 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/


#include "AlienCommandDialog.h"
#include "AlienCommandModel.h"

#include "ColumnSelectionMenu.h"
#include "ColumnSortingMenu.h"
#include "ContextMenu.h"
#include "Icons.h"
#include "IconEngine.h"
#include "IconSize.h"
#include "TreeView.h"

#include <QtGui/QHeaderView>
#include <QtGui/QShortcut>

//__________________________________________________
AlienCommandDialog::AlienCommandDialog( QWidget* parent ):
    CustomDialog( parent, CloseButton ),
    model_( 0 )
{

    Debug::Throw( "AlienCommandDialog::AlienCommandDialog.\n" );
    setWindowTitle( "Command List - Gridwatch" );

    // customize layout
    layout()->setMargin(0);
    layout()->setSpacing(0);
    buttonLayout().setMargin(5);

    setAttribute( Qt::WA_DeleteOnClose );
    setOptionName( "ALIEN_COMMAND_DIALOG" );
    mainLayout().addWidget( list_ = new TreeView(this) );

    list_->header()->hide();
    list_->setSortingEnabled( true );
    list_->setIconSize( IconSize( IconSize::Medium ) );
    list_->setSelectionMode( TreeView::ContiguousSelection );

    QMenu* menu( new ContextMenu( &list() ) );
    menu->addMenu( new ColumnSortingMenu( menu, &list() ) );
    menu->addMenu( new ColumnSelectionMenu( menu, &list() ) );

    // close accelerator
    new QShortcut( QKeySequence::Close, this, SLOT( close() ) );

}

//__________________________________________________
void AlienCommandDialog::setModel( AlienCommandModel* model )
{
    list_->setModel( model );
    list_->setOptionName( "ALIEN_COMMAND_LIST" );
    model_ = model;
}
