// $Id: JdlSyntaxHighlighter.cpp,v 1.2 2012/09/11 16:19:06 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "JdlSyntaxHighlighter.h"
#include "Debug.h"

#include <QtGui/QPalette>

//__________________________________________________________
JdlSyntaxHighlighter::JdlSyntaxHighlighter( QTextDocument* parent ):
    QSyntaxHighlighter( parent ),
    Counter( "JdlSyntaxHighlighter" )
{ Debug::Throw( "JdlSyntaxHighlighter::JdlSyntaxHighlighter.\n" ); }

//__________________________________________________________
void JdlSyntaxHighlighter::highlightBlock( const QString & text )
{

    enum { IOState, ListState };

    if( previousBlockState() == IOState || previousBlockState() == ListState )
    {

        // propagate to next block
        if( text.indexOf( QRegExp( "\\}" ) ) < 0 ) setCurrentBlockState( previousBlockState() );

        // find string
        if( previousBlockState() == IOState )
        {
            QRegExp regExp( "\"(?:LF\\:)?(/.+)(?:\\,|\")" );
            regExp.setMinimal( true );
            if( text.indexOf( regExp ) >= 0 )
            {
                const int position = regExp.pos(1);
                const int length = regExp.cap(1).size();
                if( length > 0 ) _addLink( position, length );
            }
        }

    } else {

        // bold prefix
        QRegExp regExp;
        regExp.setPattern( "\\s*(\\S+)\\s*=" );
        if( text.indexOf( regExp ) >= 0 )
        {
            const int position = regExp.pos(1);
            const int length = regExp.cap(1).size();
            _addBold( position, length );
        }

        // other regexp
        regExp.setPattern( "(?:(?:OutputDir)|(?:Executable)|(?:Validationcommand))\\s*=\\s*\"(.+)\";" );
        if( text.indexOf( regExp ) >= 0 )
        {
            const int position = regExp.pos(1);
            const int length = regExp.cap(1).size();
            _addLink( position, length );
        }

        // list of files
        if( text.indexOf( QRegExp( "((OutputFile)|(InputBox)|(InputData)|(InputFile))\\s*=" ) ) >= 0 ) setCurrentBlockState( IOState );
        else if(text.indexOf( QRegExp( "\\{" ) ) >= 0 ) setCurrentBlockState( ListState );
    }

}

//__________________________________________________________
void JdlSyntaxHighlighter::_addBold( int position, int length )
{
    QTextCharFormat format;
    format.setFontWeight( QFont::DemiBold );
    setFormat( position, length, format );
}

//__________________________________________________________
void JdlSyntaxHighlighter::_addLink( int position, int length )
{
    QTextCharFormat format;
    format.setForeground( QPalette().color( QPalette::Link ) );
    setFormat( position, length, format );
}
