#ifndef JobManager_h
#define JobManager_h
// $Id: JobManager.h,v 1.24 2012/10/06 13:21:00 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "AlienCommand.h"
#include "JobModel.h"
#include "JobSet.h"
#include "TimeStamp.h"

#include <QtGui/QWidget>

class TreeView;

/*!
\class JobManager
\brief Job managment singleton
*/
class JobManager:public QWidget
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    JobManager( QWidget* );

    //! destructor
    virtual ~JobManager( void );

    //! list
    TreeView& list( void ) const
    { return *list_; }

    //! process job list
    /*! return the list of "incomplete" jobs, for which a trace command is needed */
    JobSet updateMasterList( JobSet );

    //! process job list
    /*! return the list of "incomplete" jobs, for which a trace command is needed */
    JobSet updateChildrenList( const Job&, JobSet );

    //! process job list
    /*! return the list of "incomplete" jobs, for which a trace command is needed */
    JobSet updateJobList( JobSet );

    //! update specific job
    void updateJob( const Job& );

    //! retrieve selected jobs
    JobSet selectedJobs( bool check = false );

    //! retrieve master jobs
    JobSet masterJobs( void );

    //! user
    QString user( void ) const
    { return user_; }

    //! update user
    bool setUser( QString );

    //! model
    const JobModel& model( void ) const
    { return model_; }

    signals:

    //! busy signal
    void busy( int );

    //! progress
    void progressAvailable( int );

    //! jobs
    void jobListAvailable( QString, const JobSet&, bool = true );

    //! idle
    void idle( void );

    //! message
    void messageAvailable( const QString& );

    //! request job children
    void childrenListRequested( const Job& );

    protected:

    //! update time stamps in job set based on model info
    void _updateTimeStamps( JobSet&, bool emitProgress = true );

    //! update time stamps in job set based on model info
    void _updateChildrenStatistics( JobSet& );

    //! update children statistics for master job
    void _updateChildrenStatistics( Job, JobSet );

    //! get list of jobs that need trace for updating timestamps
    JobSet _incompleteJobs( const JobSet& ) const;

    protected slots:

    //! triggered by item expansion
    void _requestChildrenList( const QModelIndex& );

    //! lock childrenList requests
    void _lockRequests( void )
    { requestsLocked_ = true; }

    //! unlock childrenList requests
    void _unlockRequests( void )
    { requestsLocked_ = false; }

    private:

    //! display list
    TreeView* list_;

    //! current user
    QString user_;

    //! job model
    JobModel model_;

    //! true when no childrenList request should be sent, on item expanded
    bool requestsLocked_;

};

#endif
