#ifndef _JobManagerFrame_h_
#define _JobManagerFrame_h_

// $Id: JobManagerFrame.h,v 1.4 2012/02/21 12:01:39 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file JobManagerFrame.h
\brief customized QVBox to recieve close event
\author Hugo Pereira
\version $Revision: 1.4 $
\date $Date: 2012/02/21 12:01:39 $
*/

#include "Counter.h"
#include "Debug.h"
#include "Key.h"

#include <QtGui/QCloseEvent>
#include <QtGui/QWidget>
#include <cassert>

class JobManager;
class SummaryFrame;

/*!
\class JobManagerFrame
\brief customized QVBox to recieve close event
*/
class JobManagerFrame: public QWidget, public Counter, public BASE::Key
{

    Q_OBJECT

    public:

    //! constructor
    JobManagerFrame( QWidget* parent = 0 );

    //! destructor
    virtual ~JobManagerFrame( void );

    //! jobManager
    JobManager& jobManager( void ) const
    {
        assert( jobManager_ );
        return *jobManager_;
    }

    //! summary frame
    SummaryFrame& summaryFrame( void ) const
    {
        assert( summaryFrame_ );
        return *summaryFrame_;
    }

    //! detached
    const bool& isDetached( void ) const
    { return detached_;  }

    //! set user (convenience function)
    void setUser( const QString& ) const;

    public slots:

    //! toggle detached
    void toggleAttached( bool state )
    { detached_ = !state; }

    private:

    //! job manager
    JobManager* jobManager_;

    //! summary frame
    SummaryFrame* summaryFrame_;

    //! true when associated summary is detached
    bool detached_;

};

#endif
