#ifndef JobModel_h
#define JobModel_h

// $Id: JobModel.h,v 1.5 2012/09/27 13:46:34 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Counter.h"
#include "Job.h"
#include "JobStatistics.h"
#include "TreeModel.h"

#include <QtGui/QColor>
#include <QtGui/QIcon>

//! Job model. Stores job information for display in lists
class JobModel : public TreeModel<Job>, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    JobModel( QObject* = 0 );

    //! destructor
    virtual ~JobModel( void )
    {}

    //!@name methods reimplemented from base class
    //@{

    //! return data
    virtual QVariant data( const QModelIndex&, int ) const;

    //! header data
    virtual QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const;

    //! number of columns for a given index
    virtual int columnCount( const QModelIndex& = QModelIndex() ) const
    { return Job::nFields + JobStatistics::nFields; }

    //@}

    protected:

    //! sorting
    virtual void _sort( int column, Qt::SortOrder order = Qt::AscendingOrder )
    { _root().sort( SortFTor( (Job::FieldType) column, order ) ); }

    private slots:

    //! configuration
    void _updateConfiguration(void);

    private:

    //! create icons
    void _createIcons( void );

    //! create icon based on column
    QIcon _createIcon( const QColor& ) const;

    //! used to sort IconCaches
    class SortFTor: public ItemModel::SortFTor
    {

        public:

        //! constructor
        SortFTor( const int& type, Qt::SortOrder order = Qt::AscendingOrder ):
            ItemModel::SortFTor( type, order )
        {}

        //! prediction
        bool operator() ( const Item& first, const Item& second ) const
        { return (*this)( first.get(), second.get() ); }

        //! prediction
        bool operator() ( Job, Job ) const;

    };

    //!@name job status icons
    //@{

    //! running jobs
    QIcon runningJobIcon_;

    //! completed jobs
    QIcon completedJobIcon_;

    //! failed jobs
    QIcon failedJobIcon_;

    //! pending jobs
    QIcon pendingJobIcon_;

    //@}

};

#endif
