// $Id: SummaryFrame.cpp,v 1.10 2012/07/20 12:09:21 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Debug.h"
#include "File.h"
#include "GridLayout.h"
#include "SummaryBar.h"
#include "SummaryFrame.h"
#include "Util.h"
#include "XmlOptions.h"

//____________________________________________________________
SummaryFrame::SummaryFrame( QWidget* parent ):
    DockPanel( parent )
{

    Debug::Throw( "SummaryFrame::SummaryFrame.\n" );

    // title
    setTitle( "Summary" );
    setOptionName( "SUMMARY_FRAME" );

    GridLayout* gridLayout = new GridLayout();
    gridLayout->setMargin(0);
    gridLayout->setSpacing( 2 );
    gridLayout->setMaxCount( 2 );
    gridLayout->setColumnAlignment( 0, Qt::AlignRight|Qt::AlignVCenter );

    panel().layout()->addItem( gridLayout );
    gridLayout->addWidget( user_ = new QLabel( &panel() ), 0, 0, 1, 2 );

    {
        user_->setAlignment( Qt::AlignHCenter );
        QFont font( user_->font() );
        font.setWeight( QFont::Bold );
        user_->setFont( font );
        user_->setVisible( false );
    }

    totalJobs_ = Label( &panel(), gridLayout, "total: " );
    completedJobs_ = Label( &panel(), gridLayout, "completed: " );
    runningJobs_ = Label( &panel(), gridLayout, "running: " );
    pendingJobs_ = Label( &panel(), gridLayout, "pending: " );
    failedJobs_ = Label( &panel(), gridLayout, "failed: " );
    unknownJobs_ = Label( &panel(), gridLayout, "unknown: " );

    gridLayout->addWidget( new QLabel( "updated: ", &panel() ) );
    gridLayout->addWidget( updated_ = new QLabel( &panel() ) );
    updated_->setText( TimeStamp::now().toString( TimeStamp::TIME_LONG ) );

    gridLayout->addWidget( summaryBar_ = new SummaryBar( &panel() ), 8, 0, 1, 2 );

}

//____________________________________________________________
void SummaryFrame::_updateJobStatistics( const JobStatistics& statistics, bool updateStamp )
{

    Debug::Throw( "SummaryFrame::_updateJobStatistics.\n" );

    bool visibilityChanged( false );
    visibilityChanged |= totalJobs_.set( statistics.get( JobStatistics::TOTAL ) );
    visibilityChanged |= pendingJobs_.set( statistics.get( JobStatistics::PENDING ) );
    visibilityChanged |= runningJobs_.set( statistics.get( JobStatistics::RUNNING ) );
    visibilityChanged |= failedJobs_.set( statistics.get( JobStatistics::FAILED ) );
    visibilityChanged |= completedJobs_.set( statistics.get( JobStatistics::COMPLETED ) );
    visibilityChanged |= unknownJobs_.set( statistics.get( JobStatistics::UNKNOWN ) );
    if( updateStamp ) updated_->setText( statistics.time().toString( TimeStamp::TIME_LONG ) );
    summaryBar_->updateJobStatistics( statistics );

    if( visibilityChanged ) main().adjustSize();

}

//____________________________________________________________
void SummaryFrame::setUser( const QString& user )
{
    Debug::Throw( "SummaryFrame::setUser.\n" );
    if( user == userName_ ) return;
    userName_ = user;

    QString host( Util::host( true ) );
    if( host == "localhost" ) user_->setText( user );
    else {

        QString buffer;
        QTextStream( &buffer ) << user << " [" << host << "]";
        user_->setText( buffer );

    }

    clear();
}

//____________________________________________________________
void SummaryFrame::_toggleDock( void )
{
    Debug::Throw( "SummaryFrame::_toggleDock.\n" );
    user_->setVisible( main().parent() != 0 );
    DockPanel::_toggleDock();
}

//____________________________________________________________
SummaryFrame::Label::Label( QWidget* parent, GridLayout* layout, const QString& name ):
    Counter( "SummaryFrame::Label" ),
    autoHide_( true ),
    label_(0),
    valueLabel_(0),
    value_(0)
{
    Debug::Throw( "SummaryFrame::Label::Label.\n" );
    layout->addWidget( label_ = new QLabel( name, parent ) );
    layout->addWidget( valueLabel_ = new QLabel( parent ) );

    setVisible( false );

}

//____________________________________________________________
bool SummaryFrame::Label::set( const int& value )
{
    assert( valueLabel_ && label_ );
    bool visibilityChanged( false );

    // check if value changed
    if( value_ == value ) return false;

    // assign new value
    value_ = value;
    valueLabel_->setText( QString().setNum( value ) );
    if( autoHide_ )
    {
        if( ( valueLabel_->isVisible() && !value ) || (!valueLabel_->isVisible() && value ) ) visibilityChanged = true;
        setVisible( value );
    }

    return visibilityChanged;

}
