// $Id: gridwatch.cpp,v 1.3 2012/09/22 07:53:45 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file    gridwatch.cpp
\brief   main
\author  Hugo Pereira
\version $Revision: 1.3 $
\date    $Date: 2012/09/22 07:53:45 $
*/

#include <QTextStream>

#include <unistd.h>
#include <signal.h>


#include "Application.h"
#include "Debug.h"
#include "DefaultOptions.h"
#include "Singleton.h"
#include "SystemOptions.h"
#include "ErrorHandler.h"
#include "Singleton.h"
#include "Job.h"

//_______________________________
//! to handle keyboard interuptions
void interrupt( int sig );

//__________________________________________
int main (int argc, char *argv[])
{

    // Ensure proper cleaning at exit
    signal(SIGINT,  interrupt);
    signal(SIGTERM, interrupt);

    // install error handler
    qInstallMsgHandler( ErrorHandler::Throw );

    // dump help
    CommandLineArguments arguments( argc, argv );
    CommandLineParser parser( Application::commandLineParser( arguments, false ) );
    if( parser.hasFlag( "--help" ) )
    {
        Application::usage();
        return 0;
    }

    // load default options
    installDefaultOptions();
    installSystemOptions();
    XmlOptions::read( XmlOptions::get().raw( "RC_FILE" ) );

    if( parser.hasOption( "--user" ) )
    { XmlOptions::get().add( "USER_NAME", Option( parser.option( "--user" ), Option::Recordable|Option::Current  ) ); }

    // initialize job fields
    Job::installFields();

    Debug::setLevel( XmlOptions::get().get<int>("DEBUG_LEVEL") );
    if( Debug::level() ) XmlOptions::get().print();

    Q_INIT_RESOURCE( basePixmaps );
    Q_INIT_RESOURCE( pixmaps );
    QApplication application( argc, argv );
    application.setApplicationName( "Gridwatch" );

    Application singleton( arguments );
    Singleton::get().setApplication( &singleton );
    singleton.initApplicationManager();

    application.exec();

    return 0;
}

//_____________________________________________
void interrupt( int sig )
{
    Debug::Throw() << "interrupt - Recieved signal " << sig << endl;
    qApp->quit();
}
